All of lore.kernel.org
 help / color / mirror / Atom feed
From: "tip-bot2 for Gabriele Paoloni" <tip-bot2@linutronix.de>
To: linux-tip-commits@vger.kernel.org
Cc: Gabriele Paoloni <gabriele.paoloni@intel.com>,
	Borislav Petkov <bp@suse.de>,
	x86@kernel.org, linux-kernel@vger.kernel.org
Subject: [tip: ras/core] x86/mce: Rename kill_it to kill_current_task
Date: Tue, 01 Dec 2020 18:05:53 -0000	[thread overview]
Message-ID: <160684595368.3364.2232510071471640636.tip-bot2@tip-bot2> (raw)
In-Reply-To: <20201127161819.3106432-6-gabriele.paoloni@intel.com>

The following commit has been merged into the ras/core branch of tip:

Commit-ID:     e1c06d2366e743475b91045ef0c2ce1bbd028cb6
Gitweb:        https://git.kernel.org/tip/e1c06d2366e743475b91045ef0c2ce1bbd028cb6
Author:        Gabriele Paoloni <gabriele.paoloni@intel.com>
AuthorDate:    Fri, 27 Nov 2020 16:18:19 
Committer:     Borislav Petkov <bp@suse.de>
CommitterDate: Tue, 01 Dec 2020 18:58:50 +01:00

x86/mce: Rename kill_it to kill_current_task

Currently, if an MCE happens in user-mode or while the kernel is copying
data from user space, 'kill_it' is used to check if execution of the
interrupted task can be recovered or not; the flag name however is not
very meaningful, hence rename it to match its goal.

 [ bp: Massage commit message, rename the queue_task_work() arg too. ]

Signed-off-by: Gabriele Paoloni <gabriele.paoloni@intel.com>
Signed-off-by: Borislav Petkov <bp@suse.de>
Link: https://lkml.kernel.org/r/20201127161819.3106432-6-gabriele.paoloni@intel.com
---
 arch/x86/kernel/cpu/mce/core.c | 16 ++++++++--------
 1 file changed, 8 insertions(+), 8 deletions(-)

diff --git a/arch/x86/kernel/cpu/mce/core.c b/arch/x86/kernel/cpu/mce/core.c
index a9991a9..6af6a3c 100644
--- a/arch/x86/kernel/cpu/mce/core.c
+++ b/arch/x86/kernel/cpu/mce/core.c
@@ -1266,14 +1266,14 @@ static void kill_me_maybe(struct callback_head *cb)
 	}
 }
 
-static void queue_task_work(struct mce *m, int kill_it)
+static void queue_task_work(struct mce *m, int kill_current_task)
 {
 	current->mce_addr = m->addr;
 	current->mce_kflags = m->kflags;
 	current->mce_ripv = !!(m->mcgstatus & MCG_STATUS_RIPV);
 	current->mce_whole_page = whole_page(m);
 
-	if (kill_it)
+	if (kill_current_task)
 		current->mce_kill_me.func = kill_me_now;
 	else
 		current->mce_kill_me.func = kill_me_maybe;
@@ -1321,10 +1321,10 @@ noinstr void do_machine_check(struct pt_regs *regs)
 	int no_way_out = 0;
 
 	/*
 	 * If kill_it gets set, there might be a way to recover from this
 	 * error.
 	 */
-	int kill_it = 0;
+	int kill_current_task = 0;
 
 	/*
 	 * MCEs are always local on AMD. Same is determined by MCG_STATUS_LMCES
@@ -1351,7 +1351,7 @@ noinstr void do_machine_check(struct pt_regs *regs)
 	 * severity is MCE_AR_SEVERITY we have other options.
 	 */
 	if (!(m.mcgstatus & MCG_STATUS_RIPV))
-		kill_it = (cfg->tolerant == 3) ? 0 : 1;
+		kill_current_task = (cfg->tolerant == 3) ? 0 : 1;
 	/*
 	 * Check if this MCE is signaled to only this logical processor,
 	 * on Intel, Zhaoxin only.
@@ -1406,7 +1406,7 @@ noinstr void do_machine_check(struct pt_regs *regs)
 		}
 	}
 
-	if (worst != MCE_AR_SEVERITY && !kill_it)
+	if (worst != MCE_AR_SEVERITY && !kill_current_task)
 		goto out;
 
 	/* Fault was in user mode and we need to take some action */
@@ -1414,7 +1414,7 @@ noinstr void do_machine_check(struct pt_regs *regs)
 		/* If this triggers there is no way to recover. Die hard. */
 		BUG_ON(!on_thread_stack() || !user_mode(regs));
 
-		queue_task_work(&m, kill_it);
+		queue_task_work(&m, kill_current_task);
 
 	} else {
 		/*
@@ -1432,7 +1432,7 @@ noinstr void do_machine_check(struct pt_regs *regs)
 		}
 
 		if (m.kflags & MCE_IN_KERNEL_COPYIN)
-			queue_task_work(&m, kill_it);
+			queue_task_work(&m, kill_current_task);
 	}
 out:
 	mce_wrmsrl(MSR_IA32_MCG_STATUS, 0);
@@ -1321,10 +1321,10 @@ noinstr void do_machine_check(struct pt_regs *regs)
 
 	/*
-	 * If kill_it gets set, there might be a way to recover from this
+	 * If kill_current_task is not set, there might be a way to recover from this
 	 * error.
 	 */

      reply	other threads:[~2020-12-01 18:07 UTC|newest]

Thread overview: 17+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2020-11-27 16:18 [PATCH v2 0/5] x86/MCE: some minor fixes Gabriele Paoloni
2020-11-27 16:18 ` [linux-safety] " Paoloni, Gabriele
2020-11-27 16:18 ` [PATCH v2 1/5] x86/mce: do not overwrite no_way_out if mce_end() fails Gabriele Paoloni
2020-11-27 16:18   ` [linux-safety] " Paoloni, Gabriele
2020-11-27 16:43   ` [tip: x86/urgent] x86/mce: Do " tip-bot2 for Gabriele Paoloni
2020-11-27 16:18 ` [PATCH v2 2/5] x86/mce: move the mce_panic() call and 'kill_it' assignments to the right places Gabriele Paoloni
2020-11-27 16:18   ` [linux-safety] " Paoloni, Gabriele
2020-12-01 18:05   ` [tip: ras/core] x86/mce: Move " tip-bot2 for Gabriele Paoloni
2020-11-27 16:18 ` [PATCH v2 3/5] x86/mce: for LMCE panic only if mca_cfg.tolerant < 3 Gabriele Paoloni
2020-11-27 16:18   ` [linux-safety] " Paoloni, Gabriele
2020-12-01 18:05   ` [tip: ras/core] x86/mce: Panic for LMCE " tip-bot2 for Gabriele Paoloni
2020-11-27 16:18 ` [PATCH v2 4/5] x86/mce: remove redundant call to irq_work_queue() Gabriele Paoloni
2020-11-27 16:18   ` [linux-safety] " Paoloni, Gabriele
2020-12-01 18:05   ` [tip: ras/core] x86/mce: Remove " tip-bot2 for Gabriele Paoloni
2020-11-27 16:18 ` [PATCH v2 5/5] x86/mce: rename kill_it as kill_current_task Gabriele Paoloni
2020-11-27 16:18   ` [linux-safety] " Paoloni, Gabriele
2020-12-01 18:05   ` tip-bot2 for Gabriele Paoloni [this message]

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=160684595368.3364.2232510071471640636.tip-bot2@tip-bot2 \
    --to=tip-bot2@linutronix.de \
    --cc=bp@suse.de \
    --cc=gabriele.paoloni@intel.com \
    --cc=linux-kernel@vger.kernel.org \
    --cc=linux-tip-commits@vger.kernel.org \
    --cc=x86@kernel.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.